import {
  select,
  scaleLinear,
  scaleTime,
  line,
  extent,
  range,
  domain,
} from 'd3';

import { axis } from './axis';

export function scatterPlot(container, { data }) {
  const margin = {
    left: 60,
    right: 40,
    top: 30,
    bottom: 50,
  };
  const width = innerWidth;
  const height = innerHeight;

  const xValue = (d) => d.date;
  const yValue = (d) => d.average;

  const xScale = scaleTime()
    .domain(extent(data, xValue))
    .range([margin.left, width - margin.right]);
  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([height - margin.bottom, margin.top]);

  const svg = select(container)
    .selectAll('svg')
    .data([null])
    .join('svg')
    .attr('width', width)
    .attr('height', height)
    .style('background', 'rgb(0,0,30)');

  svg
    .selectAll('circle')
    .data(data)
    .join('circle')
    .attr('r', 1)
    .attr('opacity', 600 / 1000)
    .attr('fill', `hsl(${Math.random() * 360},100%,70%)`)
    .attr('cx', (d) => xScale(xValue(d)))
    .attr('cy', (d) => yScale(yValue(d)));

  const lineGenaretor = line()
    .x((d) => xScale(xValue(d)))
    .y((d) => yScale(yValue(d)));

  svg
    .selectAll('path.line')
    .data([null])
    .join('path')

    .attr('class', 'line')
    .attr('stroke', `hsl(${Math.random() * 300},50%,50%)`)
    .attr('fill', 'none')
    .attr('stroke-width', '0.7')

    .attr('d', lineGenaretor(data));

  svg.call(axis, { xScale, yScale });
}
